@@ -52,6 +52,7 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #ifdef HAVE_EXIF
+#include "eog-exif-util.h"
 #include <libexif/exif-data.h>
 #include <libexif/exif-utils.h>
 #include <libexif/exif-loader.h>
@@ -1256,9 +1257,11 @@ eog_image_load (EogImage *img, EogImageData data2read, EogJob *job, GError **err
 
 #ifdef HAVE_EXIF
 	/* Check that the metadata was loaded at least once before
-	 * trying to autorotate. */
+	 * trying to autorotate. Also only an image load job should try to
+	 * autorotate an image. */
 	if (priv->autorotate && 
-	    priv->metadata_status == EOG_IMAGE_METADATA_READY) {
+	    priv->metadata_status == EOG_IMAGE_METADATA_READY &&
+	    data2read & EOG_IMAGE_DATA_IMAGE) {
 		eog_image_real_autorotate (img);
 	}
 #endif
@@ -1885,28 +1888,27 @@ eog_image_cancel_load (EogImage *img)
 	g_mutex_unlock (priv->status_mutex);
 }
 
-gpointer
+#ifdef HAVE_EXIF
+EogExifData *
 eog_image_get_exif_info (EogImage *img)
 {
 	EogImagePrivate *priv;
-	gpointer data = NULL;
+	EogExifData *data = NULL;
 
 	g_return_val_if_fail (EOG_IS_IMAGE (img), NULL);
 
 	priv = img->priv;
 
-#ifdef HAVE_EXIF
 	g_mutex_lock (priv->status_mutex);
 
 	exif_data_ref (priv->exif);
 	data = priv->exif;
 
 	g_mutex_unlock (priv->status_mutex);
-#endif
 
 	return data;
 }
-
+#endif
 
 gpointer
 eog_image_get_xmp_info (EogImage *img)
