@@ -71,23 +71,23 @@ eog_thumb_view_finalize (GObject *object)
 }
 
 static void
-eog_thumb_view_destroy (GtkObject *object)
+eog_thumb_view_destroy (GtkWidget *object)
 {
 	EogThumbView *thumbview;
 	g_return_if_fail (EOG_IS_THUMB_VIEW (object));
 	thumbview = EOG_THUMB_VIEW (object);
 
-	GTK_OBJECT_CLASS (eog_thumb_view_parent_class)->destroy (object);
+	GTK_WIDGET_CLASS (eog_thumb_view_parent_class)->destroy (object);
 }
 
 static void
 eog_thumb_view_class_init (EogThumbViewClass *class)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (class);
-	GtkObjectClass *object_class = GTK_OBJECT_CLASS (class);
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
 
 	gobject_class->finalize = eog_thumb_view_finalize;
-	object_class->destroy = eog_thumb_view_destroy;
+	widget_class->destroy = eog_thumb_view_destroy;
 
 	g_type_class_add_private (class, sizeof (EogThumbViewPrivate));
 }
@@ -225,7 +225,7 @@ thumbview_on_adjustment_changed_cb (EogThumbView *thumbview,
 
 static void
 thumbview_on_parent_set_cb (GtkWidget *widget,
-			    GtkObject *old_parent,
+			    GtkWidget *old_parent,
 			    gpointer   user_data)
 {
 	EogThumbView *thumbview = EOG_THUMB_VIEW (widget);
@@ -402,7 +402,7 @@ thumbview_get_tooltip_string (EogImage *image)
 		gchar time_buffer[32];
 
 		date = eog_exif_util_format_date (
-			eog_exif_util_get_value (exif_data, EXIF_TAG_DATE_TIME_ORIGINAL, time_buffer, 32));
+			eog_exif_data_get_value (exif_data, EXIF_TAG_DATE_TIME_ORIGINAL, time_buffer, 32));
 
 		if (date) {
 			extra_info = g_strdup_printf ("\n%s %s", _("Taken on"), date);
@@ -819,7 +819,7 @@ eog_thumb_view_select_single (EogThumbView *thumbview,
 			path = gtk_tree_path_new_from_indices (n_items - 1, -1);
 			break;
 		case EOG_THUMB_VIEW_SELECT_RANDOM:
-			path = gtk_tree_path_new_from_indices ((int)(((float)(n_items - 1) * rand()) / (float)(RAND_MAX + 1.f)), -1);
+			path = gtk_tree_path_new_from_indices (g_random_int_range (0, n_items), -1);
 			break;
 		}
 	} else {
@@ -857,7 +857,7 @@ eog_thumb_view_select_single (EogThumbView *thumbview,
 			break;
 		case EOG_THUMB_VIEW_SELECT_RANDOM:
 			gtk_tree_path_free (path);
-			path = gtk_tree_path_new_from_indices ((int)(((float)(n_items - 1) * rand()) / (float)(RAND_MAX + 1.f)), -1);
+			path = gtk_tree_path_new_from_indices (g_random_int_range (0, n_items), -1);
 			break;
 		}
 	}
