@@ -31,8 +31,7 @@
 #ifndef GNOME_DESKTOP_USE_UNSTABLE_API
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 #endif
-#include <libgnomeui/gnome-desktop-thumbnail.h>
-#include <libart_lgpl/art_rgb.h>
+#include <libgnome-desktop/gnome-desktop-thumbnail.h>
 
 #include "eog-thumbnail.h"
 #include "eog-list-store.h"
@@ -276,14 +275,12 @@ eog_thumbnail_stretch_frame_image (GdkPixbuf *frame_image,
 				   gboolean fill_flag)
 {
         GdkPixbuf *result_pixbuf;
-        guchar *pixels_ptr;
         gint frame_width, frame_height;
-        gint y, row_stride;
         gint target_width, target_frame_width;
         gint target_height, target_frame_height;
 
         frame_width  = gdk_pixbuf_get_width  (frame_image);
-        frame_height = gdk_pixbuf_get_height (frame_image );
+        frame_height = gdk_pixbuf_get_height (frame_image);
 
         if (fill_flag) {
 		result_pixbuf = gdk_pixbuf_scale_simple (frame_image,
@@ -296,19 +293,9 @@ eog_thumbnail_stretch_frame_image (GdkPixbuf *frame_image,
 						8,
 						dest_width,
 						dest_height);
-        }
 
-        row_stride = gdk_pixbuf_get_rowstride (result_pixbuf);
-        pixels_ptr = gdk_pixbuf_get_pixels (result_pixbuf);
-
-        if (!fill_flag) {
-        	for (y = 0; y < dest_height; y++) {
-			art_rgb_run_alpha (pixels_ptr,
-					   255, 255,
-					   255, 255,
-					   dest_width);
-			pixels_ptr += row_stride;
-        	}
+		/* Clear pixbuf to fully opaque white */
+		gdk_pixbuf_fill (result_pixbuf, 0xffffffff);
         }
 
         target_width  = dest_width - left_offset - right_offset;
@@ -390,15 +377,15 @@ eog_thumbnail_stretch_frame_image (GdkPixbuf *frame_image,
         return result_pixbuf;
 }
 
-void
-eog_thumbnail_add_frame (GdkPixbuf **thumbnail)
+GdkPixbuf *
+eog_thumbnail_add_frame (GdkPixbuf *thumbnail)
 {
 	GdkPixbuf *result_pixbuf;
 	gint source_width, source_height;
 	gint dest_width, dest_height;
 
-	source_width  = gdk_pixbuf_get_width  (*thumbnail);
-	source_height = gdk_pixbuf_get_height (*thumbnail);
+	source_width  = gdk_pixbuf_get_width  (thumbnail);
+	source_height = gdk_pixbuf_get_height (thumbnail);
 
 	dest_width  = source_width  + 9;
 	dest_height = source_height + 9;
@@ -409,25 +396,23 @@ eog_thumbnail_add_frame (GdkPixbuf **thumbnail)
 							   dest_height,
 							   FALSE);
 
-	gdk_pixbuf_copy_area (*thumbnail,
+	gdk_pixbuf_copy_area (thumbnail,
 			      0, 0,
 			      source_width,
 			      source_height,
 			      result_pixbuf,
 			      3, 3);
 
-	g_object_unref (*thumbnail);
-
-	*thumbnail = result_pixbuf;
+	return result_pixbuf;
 }
 
-void
-eog_thumbnail_fit_to_size (GdkPixbuf **thumbnail, gint dimension)
+GdkPixbuf *
+eog_thumbnail_fit_to_size (GdkPixbuf *thumbnail, gint dimension)
 {
 	gint width, height;
 
-	width = gdk_pixbuf_get_width (*thumbnail);
-	height = gdk_pixbuf_get_height (*thumbnail);
+	width = gdk_pixbuf_get_width (thumbnail);
+	height = gdk_pixbuf_get_height (thumbnail);
 
 	if (width > dimension || height > dimension) {
 		GdkPixbuf *result_pixbuf;
@@ -442,12 +427,11 @@ eog_thumbnail_fit_to_size (GdkPixbuf **thumbnail, gint dimension)
 		width  = MAX (width  * factor, 1);
 		height = MAX (height * factor, 1);
 
-		result_pixbuf = gnome_desktop_thumbnail_scale_down_pixbuf (*thumbnail, width, height);
+		result_pixbuf = gnome_desktop_thumbnail_scale_down_pixbuf (thumbnail, width, height);
 
-		g_object_unref (*thumbnail);
-
-		*thumbnail = result_pixbuf;
+		return result_pixbuf;
 	}
+	return gdk_pixbuf_copy (thumbnail);
 }
 
 GdkPixbuf*
@@ -456,7 +440,7 @@ eog_thumbnail_load (EogImage *image, GError **error)
 	GdkPixbuf *thumb = NULL;
 	GFile *file;
 	EogThumbData *data;
-	GdkPixbuf *pixbuf;
+	GdkPixbuf *pixbuf = NULL;
 
 	g_return_val_if_fail (image != NULL, NULL);
 	g_return_val_if_fail (error != NULL && *error == NULL, NULL);
@@ -481,7 +465,9 @@ eog_thumbnail_load (EogImage *image, GError **error)
 	if (thumb != NULL) {
 		eog_debug_message (DEBUG_THUMBNAIL, "%s: loaded from cache",data->uri_str);
 	} else if (gnome_desktop_thumbnail_factory_can_thumbnail (factory, data->uri_str, data->mime_type, data->mtime)) {
-		pixbuf = eog_image_get_pixbuf (image);
+		/* Only use the image pixbuf when it is up to date. */
+		if (!eog_image_is_file_changed (image))
+			pixbuf = eog_image_get_pixbuf (image);
 
 		if (pixbuf != NULL) {
 			/* generate a thumbnail from the in-memory image,
